@@ -2605,3 +2605,77 @@ int sysinfo(int command, char *buf, long count)
     }
 }
 #endif
+
+#ifdef TIME64_HACK
+int WRAP_LSTAT64_TIME64 LSTAT64_TIME64_ARG(int ver,
+		       const char *file_name,
+		       struct stat64 *statbuf){
+
+  int r;
+
+#ifdef LIBFAKEROOT_DEBUGGING
+  if (fakeroot_debug) {
+    fprintf(stderr, "lstat[time64] file_name %s\n", file_name);
+  }
+#endif /* LIBFAKEROOT_DEBUGGING */
+  r=NEXT_LSTAT64_TIME64(ver, file_name, statbuf);
+  if(r)
+    return -1;
+  SEND_GET_STAT64(statbuf, ver);
+  return 0;
+}
+
+
+int WRAP_STAT64_TIME64 STAT64_TIME64_ARG(int ver,
+		       const char *file_name,
+		       struct stat64 *st){
+  int r;
+
+#ifdef LIBFAKEROOT_DEBUGGING
+  if (fakeroot_debug) {
+    fprintf(stderr, "stat64[time64] file_name %s\n", file_name);
+  }
+#endif /* LIBFAKEROOT_DEBUGGING */
+  r=NEXT_STAT64_TIME64(ver, file_name, st);
+  if(r)
+    return -1;
+  SEND_GET_STAT64(st,ver);
+  return 0;
+}
+
+
+int WRAP_FSTAT64_TIME64 FSTAT64_TIME64_ARG(int ver,
+			int fd,
+			struct stat64 *st){
+
+  int r;
+
+#ifdef LIBFAKEROOT_DEBUGGING
+  if (fakeroot_debug) {
+    fprintf(stderr, "fstat64[time64] fd %d\n", fd);
+  }
+#endif /* LIBFAKEROOT_DEBUGGING */
+  r=NEXT_FSTAT64_TIME64(ver, fd, st);
+  if(r)
+    return -1;
+  SEND_GET_STAT64(st,ver);
+  return 0;
+}
+
+int WRAP_FSTATAT64_TIME64 FSTATAT64_TIME64_ARG(int ver,
+			     int dir_fd,
+			     const char *path,
+			     struct stat64 *st,
+			     int flags){
+
+
+  int r;
+
+  r=NEXT_FSTATAT64_TIME64(ver, dir_fd, path, st, flags);
+  if(r)
+    return -1;
+  SEND_GET_STAT64(st,ver);
+  return 0;
+}
+
+#endif /* TIME64_HACK */
